.. mat-data documentation master file, created by
   sphinx-quickstart on Fri May 17 17:33:21 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to MAT-data's documentation!
====================================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

MAT-data
========
.. automodule:: matdata
   :members:

----

.. include:: ../../matdata/README.md
   :parser: myst_parser.sphinx_


Indices and tables
==================
.. toctree::
   :maxdepth: 2
   :caption: Modules:
   
   dataset
   preprocess
   converter
   generator